[−][src]Enum unicode_types::linear_b_syllabary::LinearBSyllabary
An enum to represent all characters in the LinearBSyllabary block.
Variants
LinearBSyllableB008A\u{10000}: '𐀀'
LinearBSyllableB038E\u{10001}: '𐀁'
LinearBSyllableB028I\u{10002}: '𐀂'
LinearBSyllableB061O\u{10003}: '𐀃'
LinearBSyllableB010U\u{10004}: '𐀄'
LinearBSyllableB001Da\u{10005}: '𐀅'
LinearBSyllableB045De\u{10006}: '𐀆'
LinearBSyllableB007Di\u{10007}: '𐀇'
LinearBSyllableB014Do\u{10008}: '𐀈'
LinearBSyllableB051Du\u{10009}: '𐀉'
LinearBSyllableB057Ja\u{1000a}: '𐀊'
LinearBSyllableB046Je\u{1000b}: '𐀋'
LinearBSyllableB036Jo\u{1000d}: '𐀍'
LinearBSyllableB065Ju\u{1000e}: '𐀎'
LinearBSyllableB077Ka\u{1000f}: '𐀏'
LinearBSyllableB044Ke\u{10010}: '𐀐'
LinearBSyllableB067Ki\u{10011}: '𐀑'
LinearBSyllableB070Ko\u{10012}: '𐀒'
LinearBSyllableB081Ku\u{10013}: '𐀓'
LinearBSyllableB080Ma\u{10014}: '𐀔'
LinearBSyllableB013Me\u{10015}: '𐀕'
LinearBSyllableB073Mi\u{10016}: '𐀖'
LinearBSyllableB015Mo\u{10017}: '𐀗'
LinearBSyllableB023Mu\u{10018}: '𐀘'
LinearBSyllableB006Na\u{10019}: '𐀙'
LinearBSyllableB024Ne\u{1001a}: '𐀚'
LinearBSyllableB030Ni\u{1001b}: '𐀛'
LinearBSyllableB052No\u{1001c}: '𐀜'
LinearBSyllableB055Nu\u{1001d}: '𐀝'
LinearBSyllableB003Pa\u{1001e}: '𐀞'
LinearBSyllableB072Pe\u{1001f}: '𐀟'
LinearBSyllableB039Pi\u{10020}: '𐀠'
LinearBSyllableB011Po\u{10021}: '𐀡'
LinearBSyllableB050Pu\u{10022}: '𐀢'
LinearBSyllableB016Qa\u{10023}: '𐀣'
LinearBSyllableB078Qe\u{10024}: '𐀤'
LinearBSyllableB021Qi\u{10025}: '𐀥'
LinearBSyllableB032Qo\u{10026}: '𐀦'
LinearBSyllableB060Ra\u{10028}: '𐀨'
LinearBSyllableB027Re\u{10029}: '𐀩'
LinearBSyllableB053Ri\u{1002a}: '𐀪'
LinearBSyllableB002Ro\u{1002b}: '𐀫'
LinearBSyllableB026Ru\u{1002c}: '𐀬'
LinearBSyllableB031Sa\u{1002d}: '𐀭'
LinearBSyllableB009Se\u{1002e}: '𐀮'
LinearBSyllableB041Si\u{1002f}: '𐀯'
LinearBSyllableB012So\u{10030}: '𐀰'
LinearBSyllableB058Su\u{10031}: '𐀱'
LinearBSyllableB059Ta\u{10032}: '𐀲'
LinearBSyllableB004Te\u{10033}: '𐀳'
LinearBSyllableB037Ti\u{10034}: '𐀴'
LinearBSyllableB005To\u{10035}: '𐀵'
LinearBSyllableB069Tu\u{10036}: '𐀶'
LinearBSyllableB054Wa\u{10037}: '𐀷'
LinearBSyllableB075We\u{10038}: '𐀸'
LinearBSyllableB040Wi\u{10039}: '𐀹'
LinearBSyllableB042Wo\u{1003a}: '𐀺'
LinearBSyllableB017Za\u{1003c}: '𐀼'
LinearBSyllableB074Ze\u{1003d}: '𐀽'
LinearBSyllableB020Zo\u{1003f}: '𐀿'
LinearBSyllableB025A2\u{10040}: '𐁀'
LinearBSyllableB043A3\u{10041}: '𐁁'
LinearBSyllableB085Au\u{10042}: '𐁂'
LinearBSyllableB071Dwe\u{10043}: '𐁃'
LinearBSyllableB090Dwo\u{10044}: '𐁄'
LinearBSyllableB048Nwa\u{10045}: '𐁅'
LinearBSyllableB029Pu2\u{10046}: '𐁆'
LinearBSyllableB062Pte\u{10047}: '𐁇'
LinearBSyllableB076Ra2\u{10048}: '𐁈'
LinearBSyllableB033Ra3\u{10049}: '𐁉'
LinearBSyllableB068Ro2\u{1004a}: '𐁊'
LinearBSyllableB066Ta2\u{1004b}: '𐁋'
LinearBSyllableB087Twe\u{1004c}: '𐁌'
LinearBSyllableB091Two\u{1004d}: '𐁍'
LinearBSymbolB018\u{10050}: '𐁐'
LinearBSymbolB019\u{10051}: '𐁑'
LinearBSymbolB022\u{10052}: '𐁒'
LinearBSymbolB034\u{10053}: '𐁓'
LinearBSymbolB047\u{10054}: '𐁔'
LinearBSymbolB049\u{10055}: '𐁕'
LinearBSymbolB056\u{10056}: '𐁖'
LinearBSymbolB063\u{10057}: '𐁗'
LinearBSymbolB064\u{10058}: '𐁘'
LinearBSymbolB079\u{10059}: '𐁙'
LinearBSymbolB082\u{1005a}: '𐁚'
LinearBSymbolB083\u{1005b}: '𐁛'
LinearBSymbolB086\u{1005c}: '𐁜'
LinearBSymbolB089\u{1005d}: '𐁝'
Methods
impl LinearBSyllabary[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case